@@ -9,8 +9,8 @@ build_time_vars = {'ABIFLAGS': '',
  'BASECPPFLAGS': '',
  'BASEMODLIBS': '',
  'BINDIR': '/usr/pkg/bin',
- 'BINLIBDEST': '/usr/pkg/lib/python3.6',
- 'BLDLIBRARY': '-L. -lpython3.6',
+ 'BINLIBDEST': '/usr/pkg/lib/python3.7',
+ 'BLDLIBRARY': '-L. -lpython3.7',
  'BLDSHARED': 'gcc -pthread -shared -L. -L/usr/lib -Wl,-R/usr/lib '
               '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/X11R7/lib '
               '-Wl,-R/usr/X11R7/lib -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
@@ -34,17 +34,16 @@ build_time_vars = {'ABIFLAGS': '',
                      '-I/usr/pkg/include',
  'CONFIGURE_CFLAGS_NODIST': '-std=gnu99 -Wextra -Wno-unused-result '
                             '-Wno-unused-parameter '
-                            '-Wno-missing-field-initializers',
+                            '-Wno-missing-field-initializers '
+                            '-Werror=implicit-function-declaration',
  'CONFIGURE_CPPFLAGS': '-I/usr/include -I/usr/pkg/include',
  'CONFIGURE_LDFLAGS': '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
                       '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib '
                       '-Wl,-R/usr/X11R7/lib',
- 'CONFIGURE_LDFLAGS_NODIST': '',
- 'CONFIG_ARGS': "'--enable-shared' '--with-system-ffi' '--with-threads' "
-                "'--without-ensurepip' '--without-pymalloc' "
+ 'CONFIG_ARGS': "'--enable-shared' '--with-openssl=/usr' '--with-system-ffi' "
+                "'--with-threads' '--without-ensurepip' '--without-pymalloc' "
                 "'--prefix=/usr/pkg' '--build=armv7--netbsdelf-eabihf' "
                 "'--host=armv7--netbsdelf-eabihf' '--mandir=/usr/pkg/man' "
-                "'--enable-option-checking=yes' "
                 "'build_alias=armv7--netbsdelf-eabihf' "
                 "'host_alias=armv7--netbsdelf-eabihf' 'CC=gcc' 'CFLAGS=-O2 "
                 "-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include' "
@@ -52,28 +51,28 @@ build_time_vars = {'ABIFLAGS': '',
                 "-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib' "
                 "'LIBS=' 'CPPFLAGS=-I/usr/include -I/usr/pkg/include' "
                 "'PKG_CONFIG=' 'PKG_CONFIG_PATH=' "
-                "'PKG_CONFIG_LIBDIR=/mnt/earmv7hf/pkgsrc/lang/python36/work.earmv7hf/.buildlink/lib/pkgconfig:/mnt/earmv7hf/pkgsrc/lang/python36/work.earmv7hf/.buildlink/share/pkgconfig'",
+                "'PKG_CONFIG_LIBDIR=/mnt/earmv7hf/pkgsrc/lang/python37/work.earmv7hf/.buildlink/lib/pkgconfig:/mnt/earmv7hf/pkgsrc/lang/python37/work.earmv7hf/.buildlink/share/pkgconfig'",
  'CONFINCLUDEDIR': '/usr/pkg/include',
- 'CONFINCLUDEPY': '/usr/pkg/include/python3.6',
- 'COREPYTHONPATH': ':',
- 'COVERAGE_INFO': '/mnt/earmv7hf/pkgsrc/lang/python36/work.earmv7hf/Python-3.6.9/coverage.info',
- 'COVERAGE_REPORT': '/mnt/earmv7hf/pkgsrc/lang/python36/work.earmv7hf/Python-3.6.9/lcov-report',
+ 'CONFINCLUDEPY': '/usr/pkg/include/python3.7',
+ 'COREPYTHONPATH': '',
+ 'COVERAGE_INFO': '/mnt/earmv7hf/pkgsrc/lang/python37/work.earmv7hf/Python-3.7.1/coverage.info',
+ 'COVERAGE_REPORT': '/mnt/earmv7hf/pkgsrc/lang/python37/work.earmv7hf/Python-3.7.1/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include -I/usr/include -I/usr/pkg/include -I/usr/include '
              '-I/usr/pkg/include',
  'CXX': 'c++ -pthread',
- 'DESTDIRS': '/usr/pkg /usr/pkg/lib /usr/pkg/lib/python3.6 '
-             '/usr/pkg/lib/python3.6/lib-dynload',
- 'DESTLIB': '/usr/pkg/lib/python3.6',
+ 'DESTDIRS': '/usr/pkg /usr/pkg/lib /usr/pkg/lib/python3.7 '
+             '/usr/pkg/lib/python3.7/lib-dynload',
+ 'DESTLIB': '/usr/pkg/lib/python3.7',
  'DESTPATH': '',
- 'DESTSHARED': '/usr/pkg/lib/python3.6/lib-dynload',
+ 'DESTSHARED': '/usr/pkg/lib/python3.7/lib-dynload',
  'DFLAGS': '',
  'DIRMODE': 755,
- 'DIST': 'README ChangeLog configure configure.ac acconfig.h pyconfig.h.in '
+ 'DIST': 'README.rst ChangeLog configure configure.ac acconfig.h pyconfig.h.in '
          'Makefile.pre.in Include Lib Misc Ext-dummy',
  'DISTDIRS': 'Include Lib Misc Ext-dummy',
- 'DISTFILES': 'README ChangeLog configure configure.ac acconfig.h '
+ 'DISTFILES': 'README.rst ChangeLog configure configure.ac acconfig.h '
               'pyconfig.h.in Makefile.pre.in',
  'DLINCLDIR': '.',
  'DLLLIBRARY': '',
@@ -89,7 +88,6 @@ build_time_vars = {'ABIFLAGS': '',
  'ENSUREPIP': 'no',
  'EXE': '',
  'EXEMODE': 755,
- 'EXTRAMACHDEPPATH': '',
  'EXTRATESTOPTS': '',
  'EXTRA_CFLAGS': '',
  'EXT_SUFFIX': '.so',
@@ -156,6 +154,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_DECL_RTLD_GLOBAL': 1,
  'HAVE_DECL_RTLD_LAZY': 1,
  'HAVE_DECL_RTLD_LOCAL': 1,
+ 'HAVE_DECL_RTLD_MEMBER': 0,
  'HAVE_DECL_RTLD_NODELETE': 1,
  'HAVE_DECL_RTLD_NOLOAD': 1,
  'HAVE_DECL_RTLD_NOW': 1,
@@ -282,6 +281,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_LINUX_NETLINK_H': 0,
  'HAVE_LINUX_RANDOM_H': 0,
  'HAVE_LINUX_TIPC_H': 0,
+ 'HAVE_LINUX_VM_SOCKETS_H': 0,
  'HAVE_LOCKF': 1,
  'HAVE_LOG1P': 1,
  'HAVE_LOG2': 1,
@@ -290,7 +290,6 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_LUTIMES': 1,
  'HAVE_MAKEDEV': 1,
  'HAVE_MBRTOWC': 1,
- 'HAVE_MEMMOVE': 1,
  'HAVE_MEMORY_H': 1,
  'HAVE_MEMRCHR': 1,
  'HAVE_MKDIRAT': 1,
@@ -317,12 +316,15 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_POLL_H': 1,
  'HAVE_POSIX_FADVISE': 1,
  'HAVE_POSIX_FALLOCATE': 1,
+ 'HAVE_POSIX_SPAWN': 1,
  'HAVE_PREAD': 1,
+ 'HAVE_PREADV': 1,
+ 'HAVE_PREADV2': 0,
  'HAVE_PRLIMIT': 0,
  'HAVE_PROCESS_H': 0,
  'HAVE_PROTOTYPES': 1,
- 'HAVE_PTHREAD_ATFORK': 1,
  'HAVE_PTHREAD_DESTRUCTOR': 0,
+ 'HAVE_PTHREAD_GETCPUCLOCKID': 1,
  'HAVE_PTHREAD_H': 1,
  'HAVE_PTHREAD_INIT': 0,
  'HAVE_PTHREAD_KILL': 1,
@@ -330,13 +332,14 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_PTY_H': 0,
  'HAVE_PUTENV': 1,
  'HAVE_PWRITE': 1,
+ 'HAVE_PWRITEV': 1,
+ 'HAVE_PWRITEV2': 0,
  'HAVE_READLINK': 1,
  'HAVE_READLINKAT': 1,
  'HAVE_READV': 1,
  'HAVE_REALPATH': 1,
  'HAVE_RENAMEAT': 1,
  'HAVE_RL_APPEND_HISTORY': 1,
- 'HAVE_RL_CALLBACK': 1,
  'HAVE_RL_CATCH_SIGNAL': 1,
  'HAVE_RL_COMPLETION_APPEND_CHARACTER': 1,
  'HAVE_RL_COMPLETION_DISPLAY_MATCHES_HOOK': 1,
@@ -351,7 +354,6 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SCHED_SETAFFINITY': 0,
  'HAVE_SCHED_SETPARAM': 1,
  'HAVE_SCHED_SETSCHEDULER': 1,
- 'HAVE_SELECT': 1,
  'HAVE_SEM_GETVALUE': 1,
  'HAVE_SEM_OPEN': 1,
  'HAVE_SEM_TIMEDWAIT': 1,
@@ -377,6 +379,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SHADOW_H': 0,
  'HAVE_SIGACTION': 1,
  'HAVE_SIGALTSTACK': 1,
+ 'HAVE_SIGINFO_T_SI_BAND': 1,
  'HAVE_SIGINTERRUPT': 1,
  'HAVE_SIGNAL_H': 1,
  'HAVE_SIGPENDING': 1,
@@ -478,6 +481,11 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_UTIMENSAT': 1,
  'HAVE_UTIMES': 1,
  'HAVE_UTIME_H': 1,
+ 'HAVE_UUID_CREATE': 1,
+ 'HAVE_UUID_ENC_BE': 1,
+ 'HAVE_UUID_GENERATE_TIME_SAFE': 1,
+ 'HAVE_UUID_H': 1,
+ 'HAVE_UUID_UUID_H': 1,
  'HAVE_WAIT3': 1,
  'HAVE_WAIT4': 1,
  'HAVE_WAITID': 1,
@@ -489,19 +497,20 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_WMEMCMP': 1,
  'HAVE_WORKING_TZSET': 1,
  'HAVE_WRITEV': 1,
+ 'HAVE_X509_VERIFY_PARAM_SET1_HOST': 1,
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
  'HOST_GNU_TYPE': 'armv7--netbsdelf-eabihf',
  'INCLDIRSTOMAKE': '/usr/pkg/include /usr/pkg/include '
-                   '/usr/pkg/include/python3.6 /usr/pkg/include/python3.6',
+                   '/usr/pkg/include/python3.7 /usr/pkg/include/python3.7',
  'INCLUDEDIR': '/usr/pkg/include',
- 'INCLUDEPY': '/usr/pkg/include/python3.6',
+ 'INCLUDEPY': '/usr/pkg/include/python3.7',
  'INSTALL': '/usr/bin/install -c -o root -g wheel',
  'INSTALL_DATA': '/usr/bin/install -c -o root -g wheel -m 644',
  'INSTALL_PROGRAM': '/usr/bin/install -c -s -o root -g wheel -m 755',
  'INSTALL_SCRIPT': '/usr/bin/install -c -o root -g wheel -m 755',
  'INSTALL_SHARED': '/usr/bin/install -c -o root -g wheel -m 555',
- 'INSTSONAME': 'libpython3.6.so.1.0',
+ 'INSTSONAME': 'libpython3.7.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'c++ -pthread -shared',
@@ -509,25 +518,24 @@ build_time_vars = {'ABIFLAGS': '',
             '-L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib -L/usr/lib -Wl,-R/usr/lib '
             '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/X11R7/lib '
             '-Wl,-R/usr/X11R7/lib',
- 'LDFLAGS_NODIST': '',
  'LDLAST': '',
- 'LDLIBRARY': 'libpython3.6.so',
+ 'LDLIBRARY': 'libpython3.7.so',
  'LDLIBRARYDIR': '',
  'LDSHARED': 'gcc -pthread -shared -L. -L/usr/lib -Wl,-R/usr/lib '
              '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/X11R7/lib '
              '-Wl,-R/usr/X11R7/lib -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
              '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
- 'LDVERSION': '3.6',
+ 'LDVERSION': '3.7',
  'LIBC': '',
- 'LIBDEST': '/usr/pkg/lib/python3.6',
+ 'LIBDEST': '/usr/pkg/lib/python3.7',
  'LIBDIR': '/usr/pkg/lib',
  'LIBFFI_INCLUDEDIR': '',
  'LIBM': '-lm',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
  'LIBPC': '/usr/pkg/lib/pkgconfig',
- 'LIBPL': '/usr/pkg/lib/python3.6/config-3.6',
- 'LIBRARY': 'libpython3.6.a',
+ 'LIBPL': '/usr/pkg/lib/python3.7/config-3.7',
+ 'LIBRARY': 'libpython3.7.a',
  'LIBRARY_OBJS': '\\',
  'LIBRARY_OBJS_OMIT_FROZEN': '\\',
  'LIBS': '-lintl -lpthread  -lutil',
@@ -542,9 +550,8 @@ build_time_vars = {'ABIFLAGS': '',
  'LOCALMODLIBS': '',
  'LOG1P_DROPS_ZERO_SIGN': 0,
  'MACHDEP': 'netbsd8',
- 'MACHDEPPATH': ':',
  'MACHDEP_OBJS': '',
- 'MACHDESTLIB': '/usr/pkg/lib/python3.6',
+ 'MACHDESTLIB': '/usr/pkg/lib/python3.7',
  'MACOSX_DEPLOYMENT_TARGET': '',
  'MAINCC': 'gcc -pthread',
  'MAJOR_IN_MKDEV': 0,
@@ -552,29 +559,34 @@ build_time_vars = {'ABIFLAGS': '',
  'MAKESETUP': './Modules/makesetup',
  'MANDIR': '/usr/pkg/man',
  'MKDIR_P': '/bin/mkdir -p',
+ 'MODBUILT_NAMES': 'posix  errno  pwd  _sre  _codecs  _weakref  _functools  '
+                   '_operator  _collections  _abc  itertools  atexit  _signal  '
+                   '_stat  time  _thread  _locale  _io  zipimport  '
+                   'faulthandler  _tracemalloc  _symtable  xxsubtype',
+ 'MODDISABLED_NAMES': '',
  'MODLIBS': '',
- 'MODNAMES': '_thread posix errno pwd _sre _codecs _weakref _functools '
-             '_operator _collections itertools atexit _signal _stat time '
-             '_locale _io zipimport faulthandler _tracemalloc _symtable '
-             'xxsubtype',
- 'MODOBJS': 'Modules/_threadmodule.o  Modules/posixmodule.o  '
-            'Modules/errnomodule.o  Modules/pwdmodule.o  Modules/_sre.o  '
-            'Modules/_codecsmodule.o  Modules/_weakref.o  '
-            'Modules/_functoolsmodule.o  Modules/_operator.o  '
-            'Modules/_collectionsmodule.o  Modules/itertoolsmodule.o  '
+ 'MODOBJS': 'Modules/posixmodule.o  Modules/errnomodule.o  '
+            'Modules/pwdmodule.o  Modules/_sre.o  Modules/_codecsmodule.o  '
+            'Modules/_weakref.o  Modules/_functoolsmodule.o  '
+            'Modules/_operator.o  Modules/_collectionsmodule.o  '
+            'Modules/_abc.o  Modules/itertoolsmodule.o  '
             'Modules/atexitmodule.o  Modules/signalmodule.o  Modules/_stat.o  '
-            'Modules/timemodule.o  Modules/_localemodule.o  '
-            'Modules/_iomodule.o Modules/iobase.o Modules/fileio.o '
-            'Modules/bytesio.o Modules/bufferedio.o Modules/textio.o '
-            'Modules/stringio.o  Modules/zipimport.o  Modules/faulthandler.o  '
-            'Modules/_tracemalloc.o Modules/hashtable.o  '
-            'Modules/symtablemodule.o  Modules/xxsubtype.o',
+            'Modules/timemodule.o  Modules/_threadmodule.o  '
+            'Modules/_localemodule.o  Modules/_iomodule.o Modules/iobase.o '
+            'Modules/fileio.o Modules/bytesio.o Modules/bufferedio.o '
+            'Modules/textio.o Modules/stringio.o  Modules/zipimport.o  '
+            'Modules/faulthandler.o  Modules/_tracemalloc.o '
+            'Modules/hashtable.o  Modules/symtablemodule.o  '
+            'Modules/xxsubtype.o',
  'MODULE_OBJS': '\\',
  'MULTIARCH': '',
  'MULTIARCH_CPPFLAGS': '',
  'MVWDELCH_IS_EXPRESSION': 1,
  'NO_AS_NEEDED': '-Wl,--no-as-needed',
  'OBJECT_OBJS': '\\',
+ 'OPENSSL_INCLUDES': '-I/usr/include',
+ 'OPENSSL_LDFLAGS': '-L/usr/lib',
+ 'OPENSSL_LIBS': '-lssl -lcrypto',
  'OPT': '-DNDEBUG -O2 -D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
@@ -590,10 +602,10 @@ build_time_vars = {'ABIFLAGS': '',
  'PGOBJS': '\\',
  'PGO_PROF_GEN_FLAG': '-fprofile-generate',
  'PGO_PROF_USE_FLAG': '-fprofile-use -fprofile-correction',
- 'PLATDIR': '',
  'POBJS': '\\',
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
  'PROFILE_TASK': '-m test.regrtest --pgo',
+ 'PTHREAD_KEY_T_IS_COMPATIBLE_WITH_INT': 1,
  'PTHREAD_SYSTEM_SCHED_SUPPORTED': 1,
  'PURIFY': '',
  'PY3LIBRARY': '',
@@ -603,9 +615,9 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHONFRAMEWORKDIR': 'no-framework',
  'PYTHONFRAMEWORKINSTALLDIR': '',
  'PYTHONFRAMEWORKPREFIX': '',
- 'PYTHONPATH': ':',
+ 'PYTHONPATH': '',
  'PYTHON_FOR_BUILD': './python -E',
- 'PYTHON_FOR_REGEN': 'python3',
+ 'PYTHON_FOR_REGEN': 'python3.7',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 '
@@ -613,19 +625,18 @@ build_time_vars = {'ABIFLAGS': '',
               '-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include -O2 '
               '-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include',
  'PY_CFLAGS_NODIST': '-std=gnu99 -Wextra -Wno-unused-result '
-                     '-Wno-unused-parameter -Wno-missing-field-initializers',
+                     '-Wno-unused-parameter -Wno-missing-field-initializers '
+                     '-Werror=implicit-function-declaration',
+ 'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 '
                    '-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include -O2 '
                    '-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include -O2 '
                    '-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include '
                    '-std=gnu99 -Wextra -Wno-unused-result '
-                   '-Wno-unused-parameter -Wno-missing-field-initializers -I. '
-                   '-I./Include -I/usr/include -I/usr/pkg/include '
-                   '-I/usr/include -I/usr/pkg/include -fPIC -DPy_BUILD_CORE',
- 'PY_CORE_LDFLAGS': '-L. -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
-                    '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib '
-                    '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
-                    '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
+                   '-Wno-unused-parameter -Wno-missing-field-initializers '
+                   '-Werror=implicit-function-declaration -I. -I./Include '
+                   '-I/usr/include -I/usr/pkg/include -I/usr/include '
+                   '-I/usr/pkg/include -fPIC -DPy_BUILD_CORE',
  'PY_CPPFLAGS': '-I. -I./Include -I/usr/include -I/usr/pkg/include '
                 '-I/usr/include -I/usr/pkg/include',
  'PY_FORMAT_SIZE_T': '"z"',
@@ -633,7 +644,18 @@ build_time_vars = {'ABIFLAGS': '',
                '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib '
                '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib '
                '-L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
- 'PY_LDFLAGS_NODIST': '',
+ 'PY_SSL_DEFAULT_CIPHERS': 1,
+ 'PY_SSL_DEFAULT_CIPHER_STRING': 0,
+ 'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 '
+                        '-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include '
+                        '-O2 -D_FORTIFY_SOURCE=2 -I/usr/include '
+                        '-I/usr/pkg/include -O2 -D_FORTIFY_SOURCE=2 '
+                        '-I/usr/include -I/usr/pkg/include -std=gnu99 -Wextra '
+                        '-Wno-unused-result -Wno-unused-parameter '
+                        '-Wno-missing-field-initializers '
+                        '-Werror=implicit-function-declaration -I. -I./Include '
+                        '-I/usr/include -I/usr/pkg/include -I/usr/include '
+                        '-I/usr/pkg/include -fPIC',
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
  'Py_HASH_ALGORITHM': 0,
@@ -641,10 +663,10 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/mnt/earmv7hf/pkgsrc/lang/python36/work.earmv7hf/Python-3.6.9',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/mnt/earmv7hf/pkgsrc/lang/python37/work.earmv7hf/Python-3.7.1',
  'SCRIPTDIR': '/usr/pkg/lib',
  'SETPGRP_HAVE_ARG': 1,
- 'SGI_ABI': '',
+ 'SGI_ABI': '@SGI_ABI@',
  'SHELL': '/bin/sh',
  'SHLIBS': '-lintl -lpthread  -lutil',
  'SHLIB_SUFFIX': '.so',
@@ -659,6 +681,7 @@ build_time_vars = {'ABIFLAGS': '',
  'SIZEOF_LONG_LONG': 8,
  'SIZEOF_OFF_T': 8,
  'SIZEOF_PID_T': 4,
+ 'SIZEOF_PTHREAD_KEY_T': 4,
  'SIZEOF_PTHREAD_T': 4,
  'SIZEOF_SHORT': 2,
  'SIZEOF_SIZE_T': 4,
@@ -667,7 +690,7 @@ build_time_vars = {'ABIFLAGS': '',
  'SIZEOF_VOID_P': 4,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
- 'SOABI': 'cpython-36',
+ 'SOABI': 'cpython-37',
  'SRCDIRS': 'Parser Objects Python Modules Programs',
  'SRC_GDB_HOOKS': './Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
@@ -682,23 +705,20 @@ build_time_vars = {'ABIFLAGS': '',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/mnt/earmv7hf/pkgsrc/lang/python36/work.earmv7hf/Python-3.6.9 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/mnt/earmv7hf/pkgsrc/lang/python37/work.earmv7hf/Python-3.7.1 '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/mnt/earmv7hf/pkgsrc/lang/python36/work.earmv7hf/Python-3.6.9 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/mnt/earmv7hf/pkgsrc/lang/python37/work.earmv7hf/Python-3.7.1 '
                './python ./Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
- 'THREADOBJ': 'Python/thread.o',
  'TIMEMODULE_LIB': 0,
  'TIME_WITH_SYS_TIME': 1,
  'TM_IN_SYS_TIME': 0,
  'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
- 'UPDATE_FILE': 'python3 ./Tools/scripts/update_file.py',
+ 'UPDATE_FILE': 'python3.7 ./Tools/scripts/update_file.py',
  'USE_COMPUTED_GOTOS': 0,
- 'USE_INLINE': 1,
- 'VERSION': '3.6',
- 'WANT_SIGFPE_HANDLER': 0,
+ 'VERSION': '3.7',
  'WINDOW_HAS_FLAGS': 0,
  'WITH_DOC_STRINGS': 1,
  'WITH_DTRACE': 0,
@@ -706,12 +726,11 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_LIBINTL': 1,
  'WITH_NEXT_FRAMEWORK': 0,
  'WITH_PYMALLOC': 0,
- 'WITH_THREAD': 1,
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/mnt/earmv7hf/pkgsrc/lang/python36/work.earmv7hf/Python-3.6.9',
- 'abs_srcdir': '/mnt/earmv7hf/pkgsrc/lang/python36/work.earmv7hf/Python-3.6.9',
+ 'abs_builddir': '/mnt/earmv7hf/pkgsrc/lang/python37/work.earmv7hf/Python-3.7.1',
+ 'abs_srcdir': '/mnt/earmv7hf/pkgsrc/lang/python37/work.earmv7hf/Python-3.7.1',
  'datarootdir': '/usr/pkg/share',
  'exec_prefix': '/usr/pkg',
  'prefix': '/usr/pkg',
